<?php

declare(strict_types=1);

namespace Dedi\SyliusMigrationPlugin\DependencyInjection\Compiler;

use Dedi\SyliusMigrationPlugin\DependencyInjection\Configuration;
use Symfony\Component\Config\Definition\Processor;
use Symfony\Component\DependencyInjection\Compiler\CompilerPassInterface;
use Symfony\Component\DependencyInjection\ContainerBuilder;

class MigrationMappingPass implements CompilerPassInterface
{
    public function process(ContainerBuilder $container): void
    {
        $configuration = $container->getExtensionConfig('dedi_sylius_migration');
        $processor = new Processor();
        $mappingConfiguration = new Configuration();
        $configuration = $processor->processConfiguration(
            $mappingConfiguration,
            $configuration,
        );
        $mappingConfigDefinition = $container->getDefinition('dedi_migration_mapping_config');

        foreach ($configuration['migration_mapping'] as $table => $definition) {
            $mappingConfigDefinition->addMethodCall(
                'addTableMappingDefinition',
                [
                    $definition['target_table'] ?? $table,
                    $definition['table'] ?? '',
                    $definition['sql'] ?? '',
                    $definition['primary_key'],
                    $definition['identifier_mapping'],
                    $definition['fields'],
                    $definition['search'] ?? [],
                    $definition['filter'] ?? [],
                    $definition['logging_columns'] ?? [],
                    $definition['limit'],
                    $definition['date_fields'] ?? [],
                    $definition['order'] ?? null,
                    $definition['after_migrate'] ?? null,
                    $definition['handler'] ?? null,
                    $definition['error_handlers'] ?? null,
                    $definition['group'] ?? null,
                ],
            );
        }
    }
}
